bayespy.inference.vmp.nodes.multinomial.MultinomialDistribution.compute_moments_and_cgf
=======================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.multinomial

.. automethod:: MultinomialDistribution.compute_moments_and_cgf